# -*- coding: utf-8 -*-
import re
import os
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.doctest',
    'sphinx.ext.todo',
    'sphinx.ext.coverage',
    'sphinx.ext.ifconfig',
    'sphinx.ext.viewcode',
    'sphinxcontrib.napoleon'
]
if os.getenv('SPELLCHECK'):
    extensions += 'sphinxcontrib.spelling',
    spelling_show_suggestions = True
    spelling_lang = 'en_US'

try:
    import sys
    sys.path.append('src')
    import pyejabberd
    version = pyejabberd.__version__
except ImportError:
    version = '0.0.0'

source_suffix = '.rst'
master_doc = 'index'
project = u'Python API Client for Ejabberd'
copyright = u'2015, Dirk Moors'
version = release = version

import sphinx_py3doc_enhanced_theme
html_theme = "sphinx_py3doc_enhanced_theme"
html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]

pygments_style = 'trac'
templates_path = ['.']
html_use_smartypants = True
html_last_updated_fmt = '%b %d, %Y'
html_split_index = True
html_sidebars = {
   '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
}
html_short_title = '%s-%s' % (project, version)
html_theme_options = {
    'githuburl': 'https://github.com/dirkmoors/pyejabberd/'
}



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from abc import ABCMeta, abstractmethod
from six import with_metaclass


class EjabberdAPIContract(with_metaclass(ABCMeta, object)):  # pragma: no cover
    @abstractmethod
    def echo(self, sentence):
        pass

    @abstractmethod
    def registered_users(self, host):
        pass

    @abstractmethod
    def register(self, user, host, password):
        pass

    @abstractmethod
    def unregister(self, user, host):
        pass

    @abstractmethod
    def change_password(self, user, host, newpass):
        pass

    @abstractmethod
    def check_password_hash(self, user, host, password):
        pass

    @abstractmethod
    def set_nickname(self, user, host, nickname):
        pass

    @abstractmethod
    def muc_online_rooms(self, host=None):
        pass

    @abstractmethod
    def create_room(self, name, service, host):
        pass

    @abstractmethod
    def destroy_room(self, name, service, host):
        pass

    @abstractmethod
    def get_room_options(self, name, service):
        pass

    @abstractmethod
    def change_room_option(self, name, service, option, value):
        pass



# -*- coding: utf-8 -*-
from __future__ import unicode_literals, print_function
import unittest
import os

from pyejabberd import EjabberdAPIClient
from pyejabberd.muc import MUCRoomOption
from pyejabberd.errors import UserAlreadyRegisteredError
from pyejabberd.core.arguments import StringArgument, BooleanArgument, IntegerArgument, PositiveIntegerArgument
from pyejabberd.muc.arguments import MUCRoomArgument
from pyejabberd.utils import format_password_hash_md5, format_password_hash_sha



HOST = os.environ.get('PYEJABBERD_TESTS_HOST', 'localhost')
PORT = int(os.environ.get('PYEJABBERD_TESTS_PORT', 4560))
USERNAME = os.environ.get('PYEJABBERD_TESTS_USERNAME', 'admin')
PASSWORD = os.environ.get('PYEJABBERD_TESTS_PASSWORD', 'admin')
XMPP_DOMAIN = os.environ.get('PYEJABBERD_TESTS_XMPP_DOMAIN', 'example.com')
MUC_SERVICE = os.environ.get('PYEJABBERD_TESTS_MUC_SERVICE', 'conference')
PROTOCOL = os.environ.get('PYEJABBERD_TESTS_PROTOCOL', 'http')
VERBOSE = int(os.environ.get('PYEJABBERD_TESTS_VERBOSE', 0)) == 1


class EjabberdAPITests(unittest.TestCase):
    def setUp(self):
        verbose = True
        self.api = EjabberdAPIClient(
            host=HOST, port=PORT, username=USERNAME, password=PASSWORD, user_domain=XMPP_DOMAIN, protocol=PROTOCOL,
            verbose=VERBOSE)
        self.assertIsNotNone(self.api)

    def test_echo(self):
        sentence = 'TESTJE'
        result = self.api.echo(sentence)
        self.assertIsNotNone(result)
        self.assertEqual(result, sentence)

    def test_registered_users(self):
        result = self.api.registered_users(XMPP_DOMAIN)
        self.assertTrue(isinstance(result, (list, tuple)))
        self.assertTrue(self._is_registered('admin', host=XMPP_DOMAIN, registered_users=result))

    def test_register_unregister_user(self):
        username = 'test_user_123'

        result = self.api.register(username, host=XMPP_DOMAIN, password='test')
        self.assertTrue(result)
        self.assertTrue(self._is_registered(username, host=XMPP_DOMAIN))

        self._remove_user(username, host=XMPP_DOMAIN)

    def test_username_already_exists(self):
        username = 'test_user_123'

        result = self.api.register(username, host=XMPP_DOMAIN, password='test')
        self.assertTrue(result)
        self.assertTrue(self._is_registered(username, host=XMPP_DOMAIN))

        error_thrown = False
        try:
            self.api.register(username, password='test', host=XMPP_DOMAIN)
        except UserAlreadyRegisteredError:
            error_thrown = True
        self.assertTrue(error_thrown)

        self._remove_user(username, host=XMPP_DOMAIN)

    def test_change_check_password(self):
        username = 'test_user_456'

        result = self.api.register(username, host=XMPP_DOMAIN, password='test')
        self.assertTrue(result)
        self.assertTrue(self._is_registered(username, host=XMPP_DOMAIN))

        result = self.api.check_password_hash(username, host=XMPP_DOMAIN, password='test')
        self.assertTrue(result)

        result = self.api.check_password_hash(username, host=XMPP_DOMAIN, password='test2')
        self.assertFalse(result)

        result = self.api.change_password(username, host=XMPP_DOMAIN, newpass='test2')
        self.assertTrue(result)

        result = self.api.check_password_hash(username, host=XMPP_DOMAIN, password='test')
        self.assertFalse(result)

        result = self.api.check_password_hash(username, host=XMPP_DOMAIN, password='test2')
        self.assertTrue(result)

        self._remove_user(username, host=XMPP_DOMAIN)

    def test_set_nickname(self):
        username = 'test_user_789'

        result = self.api.register(username, host=XMPP_DOMAIN, password='test')
        self.assertTrue(result)
        self.assertTrue(self._is_registered(username, host=XMPP_DOMAIN))

        result = self.api.set_nickname(username, host=XMPP_DOMAIN, nickname='blabla')
        self.assertTrue(result)
        self._remove_user(username, host=XMPP_DOMAIN)

    def test_create_destroy_room(self):
        room = 'testroom_1'

        result = self.api.create_room(room, service=MUC_SERVICE, host=XMPP_DOMAIN)
        self.assertTrue(result)
        self.assertTrue(self._is_online_room(room, service=MUC_SERVICE))
        self._remove_room(room, service=MUC_SERVICE, host=XMPP_DOMAIN)

    def test_get_room_options(self):
        room = 'testroom_2'

        result = self.api.create_room(room, service=MUC_SERVICE, host=XMPP_DOMAIN)
        self.assertTrue(result)
        self.assertTrue(self._is_online_room(room, service=MUC_SERVICE))

        result = self.api.get_room_options(room, service=MUC_SERVICE)
        self.assertTrue(isinstance(result, dict))
        size = len(result)
        print(size)
        self._remove_room(room, service=MUC_SERVICE, host=XMPP_DOMAIN)

    def test_change_room_option(self):
        room = 'testroom_3'

        result = self.api.create_room(room, service=MUC_SERVICE, host=XMPP_DOMAIN)
        self.assertTrue(result)
        self.assertTrue(self._is_online_room(room, service=MUC_SERVICE))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_change_subj, value=False))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_change_subj, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_private_messages, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_private_messages, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_query_users, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_query_users, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_user_invites, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.allow_user_invites, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.anonymous, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.anonymous, value=True))

        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.description, 'test description 1'))
        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.description, 'test description 2: Füße'))

        # self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.logging, False))
        # self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.logging, True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.max_users, value=10))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.max_users, value=100))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.members_by_default, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.members_by_default, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.members_only, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.members_only, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.moderated, value=True))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.moderated, value=False))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.password, value='abcdefg'))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.password, value='51@#211323$%^&*()Füße'))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.password_protected, value=True))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.password_protected, value=False))

        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.persistent, False))
        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.persistent, True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.public, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.public, value=True))

        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.public_list, value=False))
        self.assertTrue(self.api.change_room_option(
            room, service=MUC_SERVICE, option=MUCRoomOption.public_list, value=True))

        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.subject, 'test subject 1'))
        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.subject, 'test subject 2: Füße'))

        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.subject_author, 'test author 1'))
        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.subject_author, 'test author 2: Füße'))

        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.title, 'test title 1'))
        #self.assertTrue(self.api.change_room_option(roomjid, MUCRoomOption.title, 'test title 2: Füße'))

        self._remove_room(room, service=MUC_SERVICE, host=XMPP_DOMAIN)

    def _is_registered(self, username, host, registered_users=None):
        registered_users = registered_users or self.api.registered_users(host=host)
        registered_users = [struct.get('username') for struct in registered_users]
        return username in registered_users

    def _is_online_room(self, name, service):
        online_rooms = self.api.muc_online_rooms()
        full_name = '%s@%s' % (name, service)
        return full_name in online_rooms

    def _remove_user(self, username, host):  # pragma: no cover
        attempt = 0
        while attempt < 10:
            result = self.api.unregister(username, host=host)
            if not result:
                attempt += 1
                continue
            if not self._is_registered(username, host=host):
                break
            print('_remove_user: retrying for username: %s' % username)
            attempt += 1

    def _remove_room(self, name, service, host):  # pragma: no cover
        attempt = 0
        while attempt < 10:
            result = self.api.destroy_room(name, service=service, host=host)
            if not result:
                attempt += 1
                continue
            if not self._is_online_room(name, service=service):
                break
            print('_remove_room: retrying for room: %s' % name)
            attempt += 1


class LibraryTests(unittest.TestCase):
    def test_string_argument(self):
        serializer = self._test_argument_and_get_serializer(StringArgument)

        result = serializer.to_api('abc')
        self.assertEqual(result, 'abc')

        result = serializer.to_python('abc')
        self.assertEqual(result, 'abc')

        error_thrown = False
        try:
            serializer.to_api(123)
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

        error_thrown = False
        try:
            serializer.to_python(False)
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

    def test_integer_argument(self):
        serializer = self._test_argument_and_get_serializer(IntegerArgument)

        result = serializer.to_api(123)
        self.assertEqual(result, '123')

        result = serializer.to_python('-123')
        self.assertEqual(result, -123)

        error_thrown = False
        try:
            serializer.to_api('123')
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

        error_thrown = False
        try:
            serializer.to_python('bla')
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

    def test_positive_integer_argument(self):
        serializer = self._test_argument_and_get_serializer(PositiveIntegerArgument)

        result = serializer.to_api(123)
        self.assertEqual(result, '123')

        result = serializer.to_python('123')
        self.assertEqual(result, 123)

        error_thrown = False
        try:
            serializer.to_api(-15)
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

        error_thrown = False
        try:
            serializer.to_python('-123')
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

    def test_boolean_argument(self):
        serializer = self._test_argument_and_get_serializer(BooleanArgument)

        result = serializer.to_api(True)
        self.assertEqual(result, 'true')

        result = serializer.to_api(False)
        self.assertEqual(result, 'false')

        result = serializer.to_python('true')
        self.assertEqual(result, True)

        result = serializer.to_python('false')
        self.assertEqual(result, False)

        error_thrown = False
        try:
            serializer.to_api(-15)
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

        error_thrown = False
        try:
            serializer.to_python('123')
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

    def test_mucroom_argument(self):
        serializer = self._test_argument_and_get_serializer(MUCRoomArgument)

        result = serializer.to_api(MUCRoomOption.allow_change_subj)
        self.assertEqual(result, 'allow_change_subj')

        result = serializer.to_api(MUCRoomOption.allow_change_subj.name)
        self.assertEqual(result, 'allow_change_subj')

        result = serializer.to_python('allow_change_subj')
        self.assertEqual(result, MUCRoomOption.allow_change_subj)

        error_thrown = False
        try:
            serializer.to_api(-15)
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

        error_thrown = False
        try:
            serializer.to_python('123')
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

        error_thrown = False
        try:
            serializer.to_python({})
        except ValueError:
            error_thrown = True
        self.assertTrue(error_thrown)

    def test_sha_hash(self):
        result = format_password_hash_sha('test')
        self.assertEqual(str(result), 'A94A8FE5CCB19BA61C4C873D391E987982FBBD3')

    def test_md5_hash(self):
        result = format_password_hash_md5('test')
        self.assertEqual(str(result), '98F6BCD4621D373CADE4E832627B4F6')

    def _test_argument_and_get_serializer(self, argument_class):
        arg_name = 'arg_name'
        arg_description = 'arg_description'
        arg_required = True

        # Test constructor
        arg = argument_class(arg_name, arg_description, arg_required)
        self.assertEqual(arg.name, arg_name)
        self.assertEqual(arg.description, arg_description)
        self.assertEqual(arg.required, arg_required)

        # Test Serializer class presence
        serializer_class = arg.serializer_class
        self.assertIsNotNone(serializer_class)

        # Test Serializer
        serializer = serializer_class()

        return serializer


if __name__ == '__main__':  # pragma: no cover
    unittest.main()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .core.arguments import StringArgument
from .core.definitions import API
from .core.serializers import StringSerializer
from .muc import MUCRoomOptions
from .muc.arguments import MUCRoomArgument
from .muc.enums import MUCRoomOption

from .errors import UserAlreadyRegisteredError
from .utils import format_password_hash_sha


class Echo(API):
    method = 'echothisnew'
    arguments = [StringArgument('sentence')]

    def transform_response(self, api, arguments, response):
        return response.get('repeated')


class RegisteredUsers(API):
    method = 'registered_users'
    arguments = [StringArgument('host')]

    def transform_response(self, api, arguments, response):
        return response.get('users', [])


class Register(API):
    method = 'register'
    arguments = [StringArgument('user'), StringArgument('host'), StringArgument('password')]

    def validate_response(self, api, arguments, response):
        if response.get('res') == 1:
            username = arguments.get('user')
            raise UserAlreadyRegisteredError('User with username %s already exists' % username)

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class UnRegister(API):
    method = 'unregister'
    arguments = [StringArgument('user'), StringArgument('host')]

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class ChangePassword(API):
    method = 'change_password'
    arguments = [StringArgument('user'), StringArgument('host'), StringArgument('newpass')]

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class CheckPasswordHash(API):
    method = 'check_password_hash'
    arguments = [StringArgument('user'), StringArgument('host'), StringArgument('passwordhash'),
                 StringArgument('hashmethod')]

    def transform_arguments(self, **kwargs):
        passwordhash = format_password_hash_sha(password=kwargs.pop('password'))
        kwargs.update({
            'passwordhash': passwordhash,
            'hashmethod': 'sha'
        })
        return kwargs

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class SetNickname(API):
    method = 'set_nickname'
    arguments = [StringArgument('user'), StringArgument('host'), StringArgument('nickname')]

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class MucOnlineRooms(API):
    method = 'muc_online_rooms'
    arguments = [StringArgument('host')]

    def transform_response(self, api, arguments, response):
        return [result_dict.get('room') for result_dict in response.get('rooms', {})]


class CreateRoom(API):
    method = 'create_room'
    arguments = [StringArgument('name'), StringArgument('service'), StringArgument('host')]

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class DestroyRoom(API):
    method = 'destroy_room'
    arguments = [StringArgument('name'), StringArgument('service'), StringArgument('host')]

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0


class GetRoomOptions(API):
    method = 'get_room_options'
    arguments = [StringArgument('name'), StringArgument('service')]

    def transform_response(self, api, arguments, response):
        result = {}
        for option_dict in response.get('options', []):
            option = option_dict.get('option')
            if option is None:
                raise ValueError('Unexpected option in response: ' % str(option_dict))
            name_dict, value_dict = option
            result[name_dict['name']] = value_dict['value']
        return result


class ChangeRoomOption(API):
    method = 'change_room_option'
    arguments = [StringArgument('name'), StringArgument('service'), MUCRoomArgument('option'), StringArgument('value')]

    def transform_arguments(self, **kwargs):
        option = kwargs.get('option')
        assert isinstance(option, MUCRoomOption)
        serializer_class = MUCRoomOptions.get(option.name, StringSerializer)
        kwargs['value'] = serializer_class().to_api(kwargs['value'])
        return kwargs

    def transform_response(self, api, arguments, response):
        return response.get('res') == 0



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from ..core.serializers import BooleanSerializer, StringSerializer, PositiveIntegerSerializer
from .serializers import AllowVisitorPrivateMessageSerializer
from .enums import MUCRoomOption


MUCRoomOptions = {
    MUCRoomOption.allow_change_subj.name:                    BooleanSerializer,
    MUCRoomOption.allow_private_messages.name:               BooleanSerializer,
    MUCRoomOption.allow_private_messages_from_visitors.name: AllowVisitorPrivateMessageSerializer,
    MUCRoomOption.allow_query_users.name:                    BooleanSerializer,
    MUCRoomOption.allow_user_invites.name:                   BooleanSerializer,
    MUCRoomOption.allow_visitor_nickchange.name:             BooleanSerializer,
    MUCRoomOption.allow_visitor_status.name:                 BooleanSerializer,
    MUCRoomOption.allow_voice_requests.name:                 BooleanSerializer,
    MUCRoomOption.anonymous.name:                            BooleanSerializer,
    MUCRoomOption.captcha_protected.name:                    BooleanSerializer,
    MUCRoomOption.captcha_whitelist.name:                    StringSerializer,
    MUCRoomOption.description.name:                          StringSerializer,
    MUCRoomOption.logging.name:                              BooleanSerializer,
    MUCRoomOption.max_users.name:                            PositiveIntegerSerializer,
    MUCRoomOption.members_by_default.name:                   BooleanSerializer,
    MUCRoomOption.members_only.name:                         BooleanSerializer,
    MUCRoomOption.moderated.name:                            BooleanSerializer,
    MUCRoomOption.password.name:                             StringSerializer,
    MUCRoomOption.password_protected.name:                   BooleanSerializer,
    MUCRoomOption.persistent.name:                           BooleanSerializer,
    MUCRoomOption.public.name:                               BooleanSerializer,
    MUCRoomOption.public_list.name:                          BooleanSerializer,
    MUCRoomOption.title.name:                                StringSerializer,
    MUCRoomOption.vcard.name:                                StringSerializer,
    MUCRoomOption.voice_request_min_interval.name:           PositiveIntegerSerializer
}



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .definitions import APIArgument
from .serializers import StringSerializer, IntegerSerializer, PositiveIntegerSerializer, BooleanSerializer


class StringArgument(APIArgument):
    serializer_class = StringSerializer


class IntegerArgument(APIArgument):
    serializer_class = IntegerSerializer


class PositiveIntegerArgument(APIArgument):
    serializer_class = PositiveIntegerSerializer


class BooleanArgument(APIArgument):
    serializer_class = BooleanSerializer



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from ..core.definitions import APIArgument
from .serializers import MUCRoomOptionSerializer


class MUCRoomArgument(APIArgument):
    serializer_class = MUCRoomOptionSerializer



__version__ = "0.2.2"

try:  # pragma: no cover
    # https://urllib3.readthedocs.org/en/latest/security.html#pyopenssl
    import urllib3.contrib.pyopenssl
    urllib3.contrib.pyopenssl.inject_into_urllib3()
except ImportError:
    pass

from .client import EjabberdAPIClient



# -*- encoding: utf-8 -*-
import glob
import io
import re
import sys

import os.path
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

try:
    sys.path.append('src')
    import pyejabberd
    version = pyejabberd.__version__
except ImportError:
    version = None

if sys.argv[-1] == 'publish':
    if version is None:
        raise

    os.system('python setup.py sdist upload')
    print("You probably want to also tag the version now:")
    print("  git tag -a %s -m 'version %s'" % (version, version))
    print("  git push --tags")
    sys.exit()


def read(*names, **kwargs):
    return io.open(
        join(dirname(__file__), *names),
        encoding=kwargs.get("encoding", "utf8")
    ).read()

setup(
    name="pyejabberd",
    version=version,
    license="BSD",
    description="A Python client for the Ejabberd XMLRPC API",
    long_description="%s\n%s" % (read("README.rst"), re.sub(":obj:`~?(.*?)`", r"``\1``", read("CHANGELOG.rst"))),
    author="Dirk Moors",
    author_email="dirkmoors@gmail.com",
    url="https://github.com/dirkmoors/pyejabberd",
    packages=find_packages("src"),
    package_dir={"": "src"},
    py_modules=[splitext(basename(i))[0] for i in glob.glob("src/*.py")],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Unix",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Utilities",
    ],
    keywords=[
        # eg: "keyword1", "keyword2", "keyword3",
    ],
    install_requires=[
        # eg: "aspectlib==1.1.1", "six>=1.7",
        'six>=1.9.0',
        'enum34>=1.0.4',
    ],
    extras_require={
        # eg: 'rst': ["docutils>=0.11"],
    },
    entry_points={
        "console_scripts": [
            "pyejabberd = pyejabberd.__main__:main"
        ]
    }
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from ..core.definitions import Enum


MUCRoomOption = Enum(
    'MUCRoomOption',
    ' '.join([
        'allow_change_subj',
        'allow_private_messages',
        'allow_private_messages_from_visitors',
        'allow_query_users',
        'allow_user_invites',
        'allow_visitor_nickchange',
        'allow_visitor_status',
        'allow_voice_requests',
        'anonymous',
        'captcha_protected',
        'captcha_whitelist',
        'description',
        'logging',
        'max_users',
        'members_by_default',
        'members_only',
        'moderated',
        'password',
        'password_protected',
        'persistent',
        'public',
        'public_list',
        'title',
        'vcard',
        'voice_request_min_interval',
    ]),
    module=__name__)


AllowVisitorPrivateMessage = Enum(
    'AllowVisitorPrivateMessage',
    'anyone moderators nobody',
    module=__name__)
